@@ -49,7 +49,7 @@
 .attach <- function(directory, pos = 2,
                     warn = !file.exists(directory),
                     readonly) {
-  env <- attach(NULL, pos, basename(directory))
+  env <- do.call("attach", list(NULL, pos, basename(directory)))
   attr(env, "path") <- directory
   attr(env, "readonly") <- readonly
   if (file.exists(directory)) {
@@ -75,7 +75,7 @@
   f <- function(...) {}
   body(f) <- substitute({
     Call <- match.call()
-    Call[[1]] <- quote(SOAR::NAME)
+    Call[[1]] <- NAME
     if(is.null(Call[["lib"]]))
       Call[["lib"]] <- Sys.getenv(LIB, unset = WHICH)
     if(is.null(Call[["lib.loc"]]))
@@ -88,12 +88,12 @@
   f
 }
 
-NAME <- function() NULL
+# NAME <- function() NULL
 
 Attach <- function(lib = Sys.getenv("R_LOCAL_CACHE", unset = ".R_Cache"),
                    lib.loc = Sys.getenv("R_LOCAL_LIB_LOC", unset = "."),
                    pos = 2, uniquely = TRUE, readonly = FALSE, ...) {
-  if(class((x <- substitute(lib))) == "name")
+  if(inherits(x <- substitute(lib), "name"))
     lib <- deparse(x) else lib <- lib
   if(!(file.exists(lib.loc) && file.info(lib.loc)$isdir))
     stop(lib.loc, " is not an existing directory.", call. = FALSE, domain = NA)
@@ -103,11 +103,14 @@ Attach <- function(lib = Sys.getenv("R_LOCAL_CACHE", unset = ".R_Cache"),
       stop(path, " exists but is not a directory!", call. = FALSE, domain = NA)
     fils <- .mostFiles(path)
     if(any(i <- grep("@\\.RData$", fils, invert = TRUE))) {
-      warning(paste("Converting", path, "from old filename format to new"),
-              call. = FALSE)
-      newF <- .enc(.dec(fils[i]))
-      for(j in i) file.rename(file.path(path, fils[j]),
-                              file.path(path, newF[j]))    }
+      ## warning(paste("Converting", path, "from old filename format to new"),
+      ##         call. = FALSE)
+      ## newF <- .enc(.dec(fils[i]))
+      ## for(j in i) file.rename(file.path(path, fils[j]),
+      ##                         file.path(path, newF[j]))
+      stop("Invalid cache directory. Invalid file names found: ",
+           paste(fils[i], collapse=", "))
+    }
   }
   if(uniquely)
     if(any(m <- (.pathAttributes() == path)))
@@ -122,7 +125,7 @@ Store <- function(..., list = character(0),
                   lib = Sys.getenv("R_LOCAL_CACHE", unset = ".R_Cache"),
                   lib.loc = Sys.getenv("R_LOCAL_LIB_LOC", unset = "."),
                   remove = TRUE) {
-  if(class((.x <- substitute(lib))) == "name")
+  if(inherits(.x <- substitute(lib), "name"))
     lib <- deparse(.x) else lib <- lib
   if(!(file.exists(lib.loc) && file.info(lib.loc)$isdir))
     stop(lib.loc, " is not an existing directory.", call. = FALSE, domain = NA)
@@ -157,11 +160,13 @@ Store <- function(..., list = character(0),
       stop(path, " exists but is not a directory!", call. = FALSE, domain = NA)
     fils <- .mostFiles(path)
     if(any(i <- grep("@\\.RData$", fils, invert = TRUE))) {
-      warning(paste("Converting", path, "from old filename format to new"),
-              call. = FALSE, domain = NA)
-      newF <- .enc(.dec(fils[i]))
-      for(j in i) file.rename(file.path(path, fils[j]),
-                              file.path(path, newF[j]))
+      ## warning(paste("Converting", path, "from old filename format to new"),
+      ##         call. = FALSE)
+      ## newF <- .enc(.dec(fils[i]))
+      ## for(j in i) file.rename(file.path(path, fils[j]),
+      ##                         file.path(path, newF[j]))
+      stop("Invalid cache directory. Invalid file names found: ",
+           paste(fils[i], collapse=", "))
     }
   } else dir.create(path)
   for(n in nam) {
@@ -195,7 +200,7 @@ StoreUtils <- .makeClone(Store, Utils)
 Objects <- function(lib = Sys.getenv("R_LOCAL_CACHE", unset = ".R_Cache"),
                     lib.loc = Sys.getenv("R_LOCAL_LIB_LOC", unset = "."),
                     all.names = FALSE, pattern = ".*", readonly = FALSE) {
-  if(class((x <- substitute(lib))) == "name")
+  if(inherits(x <- substitute(lib), "name"))
     lib <- deparse(x) else lib <- lib
   if(!(file.exists(lib.loc) && file.info(lib.loc)$isdir))
     stop(lib.loc, " is not an existing directory.", call. = FALSE, domain = NA)
@@ -219,7 +224,7 @@ LsData <- .makeClone(Ls, Data)
 Remove <- function(..., list = character(0),
                    lib = Sys.getenv("R_LOCAL_CACHE", unset = ".R_Cache"),
                    lib.loc = Sys.getenv("R_LOCAL_LIB_LOC", unset = ".")) {
-  if(class((.x <- substitute(lib))) == "name")
+  if(inherits(.x <- substitute(lib), "name"))
     lib <- deparse(.x) else lib <- lib
   if(!(file.exists(lib.loc) && file.info(lib.loc)$isdir))
     stop(lib.loc, " is not an existing directory.", call. = FALSE, domain = NA)
@@ -250,12 +255,13 @@ Remove <- function(..., list = character(0),
   nam <- .enc(sort(unique(nam)))
   fils <- .mostFiles(path)
   if(any(i <- grep("@\\.RData$", fils, invert = TRUE))) {
-    warning(paste("Converting", path, "from old filename format to new"),
-            call. = FALSE, domain = NA)
-    newF <- .enc(.dec(fils[i]))
-    for(j in i) file.rename(file.path(path, fils[j]),
-                            file.path(path, newF[j]))
-    fils <- .mostFiles(path)
+    ## warning(paste("Converting", path, "from old filename format to new"),
+    ##         call. = FALSE)
+    ## newF <- .enc(.dec(fils[i]))
+    ## for(j in i) file.rename(file.path(path, fils[j]),
+    ##                         file.path(path, newF[j]))
+    stop("Invalid cache directory. Invalid file names found: ",
+         paste(fils[i], collapse=", "))
   }
   mnam <- intersect(nam, fils)
   if(length(d <- setdiff(nam, mnam)) > 0)
